@@ -156,7 +156,6 @@ void button(XButtonEvent *e)
 		{
 			int skip;
 			int wasleft = c->isleft;
-			int force = (e->state & ShiftMask) == ShiftMask;
 			int ctrl = (e->state & ControlMask) == ControlMask;
 
 			if (!c->isnotile && s->skip_focus[s->desktop] && s->tile_resize[s->desktop])
@@ -174,13 +173,12 @@ void button(XButtonEvent *e)
 				top(c);
 			}
 
-			if (c->input || force)
-				active (c);
+			active (c);
 
 			if (!skip && !c->isnotile)
 				tile_all (s);
 
-                        if ((skip || wasleft || c->isnotile) && c->input && !force && !ctrl &&
+                        if ((skip || wasleft || c->isnotile) && !ctrl &&
 					s->clickthru[s->desktop] && (c->istool || c->isfloat || (c->isnotile == s->notile_raised[s->desktop])))
 				XAllowEvents (dpy, ReplayPointer, e->time);
 		}
@@ -191,7 +189,7 @@ void button(XButtonEvent *e)
 	case Button2:
 		if (c && (e->x >= BORDER) && (e->x < (c->dx + BORDER)) && (e->y >= BORDER) && (e->y < (c->dy + BORDER)))
 		{
-			if (s->clickthru[s->desktop] && c->input &&
+			if (s->clickthru[s->desktop] &&
 					(c->istool || c->isfloat || (c->isnotile == s->notile_raised[s->desktop])))
 			{
 				active (c);
@@ -205,7 +203,7 @@ void button(XButtonEvent *e)
 	case Button3:
 		if (c && (e->x >= BORDER) && (e->x < (c->dx + BORDER)) && (e->y >= BORDER) && (e->y < (c->dy + BORDER)))
 		{
-			if (s->clickthru[s->desktop] && c->input &&
+			if (s->clickthru[s->desktop] &&
 					(c->istool || c->isfloat || (c->isnotile == s->notile_raised[s->desktop])))
 			{
 				active (c);
@@ -434,10 +432,7 @@ void unhide(int n, int map)
 		wmsetstate(c, NormalState);
 		top(c);
 
-		if (c->input)
-			active(c);
-		else
-			raise_tbar (c->screen);
+		active(c);
 	}
 
 	numhidden--;
