@@ -562,7 +562,7 @@ void tile_all(ScreenInfo *s)
 				c->isleft = 1;
 			}
 
-			if (c->input && c->isleft && (mouse_on_screen () == s) && !s->notile_raised[s->desktop])
+			if (c->isleft && (mouse_on_screen () == s) && !s->notile_raised[s->desktop])
 			{
 				if (!current || !s->skip_focus[s->desktop] || !s->tile_resize[s->desktop])
 					active (c);
@@ -671,7 +671,7 @@ void revert_window (ScreenInfo *s)
 	{
 		c = prev_current;
 
-		if (c->input && !c->istool && (DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
+		if (!c->istool && (DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
 		{
 			if (c->isnotile)
 				raise_notile (s);
@@ -685,7 +685,7 @@ void revert_window (ScreenInfo *s)
 
 	for (c = clients; c; c = c->next)
 	{
-		if (c->input && !c->istool && (DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
+		if (!c->istool && (DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
 		{
 			if (c->isnotile)
 				raise_notile (s);
@@ -716,7 +716,7 @@ void revert_same (ScreenInfo *s)
 	{
 		c = prev_current;
 
-		if (c->input && !c->istool && (c->isnotile == s->notile_raised[s->desktop]) &&
+		if (!c->istool && (c->isnotile == s->notile_raised[s->desktop]) &&
 				(DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
 		{
 			active(c);
@@ -726,7 +726,7 @@ void revert_same (ScreenInfo *s)
 
 	for (c = clients; c; c = c->next)
 	{
-		if (c->input && !c->istool && (c->isnotile == s->notile_raised[s->desktop]) &&
+		if (!c->istool && (c->isnotile == s->notile_raised[s->desktop]) &&
 				(DO_TILE(c, s) || DO_RAISE_NOTILE (c, s)))
 		{
 			active(c);
@@ -745,8 +745,7 @@ void prev_window (ScreenInfo *s)
 	{
 		for (c = clients; c; c = c->next)
 		{
-			if (c->input &&
-					!c->istool &&
+			if (!c->istool &&
 					(c != current) &&
 					(c->isnotile == s->notile_raised[s->desktop]) &&
 					(DO_TILE (c, s) || DO_RAISE_NOTILE (c, s)))
@@ -768,8 +767,7 @@ void prev_window (ScreenInfo *s)
 
 	c = prev_current;
 
-	if (c->input &&
-			!c->istool &&
+	if (!c->istool &&
 			(c != current) &&
 			(c->isnotile == s->notile_raised[s->desktop]) &&
 			(DO_TILE (c, s) || DO_RAISE_NOTILE (c, s)))
@@ -799,8 +797,7 @@ void next_window (ScreenInfo *s)
 
 		for (c = clients; c; c = c->next)
 		{
-			if (c->input &&
-					!c->istool &&
+			if (!c->istool &&
 					(c != current) &&
 					(c->isnotile == s->notile_raised[s->desktop]) &&
 					(DO_TILE (c, s) || DO_RAISE_NOTILE (c, s)))
@@ -832,8 +829,7 @@ void next_window (ScreenInfo *s)
 	{
 		for (c = current->next; c; c = c->next)
 		{
-			if (c->input &&
-					!c->istool &&
+			if (!c->istool &&
 					(c != current) &&
 					(c->isnotile == s->notile_raised[s->desktop]) &&
 					(DO_TILE (c, s) || DO_RAISE_NOTILE (c, s)))
@@ -854,8 +850,7 @@ void next_window (ScreenInfo *s)
 
 	for (c = clients; c; c = c->next)
 	{
-		if (c->input &&
-				!c->istool &&
+		if (!c->istool &&
 				(c != current) &&
 				(c->isnotile == s->notile_raised[s->desktop]) &&
 				(DO_TILE (c, s) || DO_RAISE_NOTILE (c, s)))
@@ -1216,8 +1211,7 @@ void zoom (Client *c, int dimension)
 
 				for (p = clients->next; p; p = p->next)
 				{
-					if (p->input &&
-							!p->istool &&
+					if (!p->istool &&
 							(p != current) &&
 							(p->isnotile == p->screen->notile_raised[p->screen->desktop]) &&
 							(DO_TILE (p, c->screen) || DO_RAISE_NOTILE (p, c->screen)))
